# Plotting Functions

This module contains functions for generating visualizations used in the dashboard.

### Volatility Smiles

::: src.optpricing.dashboard.plots.plot_smiles_by_expiry

### 3D Volatility Surface

::: src.optpricing.dashboard.plots.plot_iv_surface_3d
